
[![PayWx](https://obrisk.oss-cn-hangzhou.aliyuncs.com/media/images/Paywx-logo.png)](https://obrisk.cn/projects/paywx/)


[![PyPI](https://dist.paywx.svg)](https://pypi.org/project/paywx)
[![Tested on Travic-ci](https://api.travis-ci.org/badges/badgerbadgerbadger.svg?branch=master&status=passed)](https://travis-ci.org)

WeChat third-party Python SDK

master: [Read the Documentation ](https://obrisk.cn/projects/paywx/)


## Features


1. Common public platforms passively respond and actively call APIs
2. WeChat Pay API
3. The third-party platform calls the API on behalf of the official account
4. Mini Program Cloud Development API


## Installation

Paywx supports Python versions 3.6, 3.7, 3.8, 3.9 and Pypy. The simplest way to install is to use pip


```bash
pip install paywx
```

Installing as a global package：

    pip install -U paywx


## Quick Start guide

This codebase comes with some examples [examples](examples/)


## Support

[GitHub issues](https://github.com/obrisk/paywx/issues)

Slack Channel

https://obrisk.slack.com/

![Paywx Slack channel for Support](https://cdn-icons-png.flaticon.com/512/2111/2111615.png)


## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](./LICENSE) file.
